---
name: Feature request
about: Suggest an idea for memoprop
title: 'Feature Request:'
---

- [ ] I have checked the [Issue tracker](../issues) and as far as I can tell, this is not a duplicate issue
- [ ] I am using the latest version of memoprop


**Is your feature request related to a problem?  Please describe.**

A clear and concise description of what the problem is - e.g. ... is frustrating.


**Describe the solution you would like**

A clear and concise description of what you want ot happen.


**Describe alternatives you've considered**

A clear and concise description of any alternative solutions or features you've considered.


**Additional information and context**

Any other information and context which might be of relevance.
